@@ -2,7 +2,7 @@
 from __future__ import absolute_import, unicode_literals
 
 import jwt.exceptions
-from django.utils.encoding import smart_text
+from django.utils.encoding import smart_str
 from django.utils.translation import ugettext as _
 from rest_framework import exceptions
 from rest_framework.authentication import BaseAuthentication, get_authorization_header
@@ -31,7 +31,7 @@ class JWTAuthentication(BaseAuthentication):
         auth = get_authorization_header(request).split()
         authenticate_header = self.authenticate_header(request=request)
 
-        if not auth or smart_text(auth[0].lower()) != authenticate_header.lower():
+        if not auth or smart_str(auth[0].lower()) != authenticate_header.lower():
             return None
 
         if len(auth) == 1:
